## 0.2.17.4 (2023-03-27)

Add default values for third-party stubs beginning with 'P' (#9957)

## 0.2.17.3 (2023-03-24)

pysftp: CnOpts.hostkeys can be None (#9937)

## 0.2.17.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.2.17.1 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.2.17 (2022-07-04)

Third-party stubs: audit more `Callable[<parameters>, Any]` annotations (#8233)

## 0.2.16 (2022-06-26)

Third-party stubs: audit `Callable[<parameters>, None]` annotations (#8175)

## 0.2.15 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 0.2.14 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 0.2.13 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.2.12 (2022-03-16)

Use PEP 604 syntax wherever possible (#7493)

## 0.2.11 (2022-03-10)

Modernize syntax in various stubs (#7469)

Use `str` and `contextlib.AbstractContextManager` instead of `typing.Text` and `typing.ContextManager`.

## 0.2.10 (2022-03-09)

Remove Python 2 support from some third-party distributions (#7466)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 0.2.9 (2022-01-16)

Cleanup: do not quote types unnecessarily (#6931)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 0.2.8 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.2.6 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 0.2.5 (2021-10-12)

Add star to all non-0.1 versions (#6146)

